Class: MetaRuby::GUI::HTML::Page

Inherits:
Qt::Object
  • Object
show all
Defined in:
lib/metaruby/gui/html/page.rb

Overview

A helper class that gives us easy-to-use page elements on a Qt::WebView

Such a page is managed as a list of sections (called Fragment). A new fragment is added or updated with #push

Direct Known Subclasses

ModelBrowser::Page

Defined Under Namespace

Classes: Fragment

Constant Summary collapse

PAGE_TEMPLATE =

The ERB template for a page

See Also:

File.join(RESSOURCES_DIR, "page.rhtml")
PAGE_BODY_TEMPLATE =

The ERB template for a page body

See Also:

File.join(RESSOURCES_DIR, "page_body.rhtml")
FRAGMENT_TEMPLATE =

The ERB template for a page fragment

See Also:

File.join(RESSOURCES_DIR, "fragment.rhtml")
LIST_TEMPLATE =

The ERB template for a list

See Also:

File.join(RESSOURCES_DIR, "list.rhtml")
ASSETS =

Assets (CSS, javascript) that are included in every page

%w{page.css jquery.min.js jquery.selectfilter.js}

Instance Attribute Summary collapse