Method: MetaRuby::GUI::HTML::Collection#linkClickedHandler
- Defined in:
- lib/metaruby/gui/html/collection.rb
#linkClickedHandler(url) ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
Handler called when a link is clicked on the page. It renders an object when the link is a link to an object of the collection, or passes the URL to the linkClicked signal otherwise.
105 106 107 108 109 110 111 112 |
# File 'lib/metaruby/gui/html/collection.rb', line 105 def linkClickedHandler(url) if url.host == "metaruby" && url.path =~ /^\/#{Regexp.quote(namespace)}(\d+)/ object = object_id_to_object[Integer($1)] render_element(object) else super end end |